@@ -1,4 +1,5 @@
 #include "main.hpp"
+#include <pybind11/stl.h>
 
 #if (U_ICU_VERSION_MAJOR_NUM >= 51)
 #include <unicode/compactdecimalformat.h>
@@ -16,28 +17,16 @@ void init_compactdecimalformat(py::module &m) {
           "__deepcopy__", [](const CompactDecimalFormat &self, py::dict) { return self.clone(); }, py::arg("memo"));
   cdf.def("clone", &CompactDecimalFormat::clone);
   cdf.def_static(
-         "create_instance",
-         [](const Locale &in_locale, UNumberCompactStyle style) {
-           ErrorCode error_code;
-           auto result = CompactDecimalFormat::createInstance(in_locale, style, error_code);
-           if (error_code.isFailure()) {
-             throw ICUError(error_code);
-           }
-           return result;
-         },
-         py::arg("in_locale"), py::arg("style"))
-      .def_static(
-          // const char *in_locale -> const Locale &in_locale
-          "create_instance",
-          [](const char *in_locale, UNumberCompactStyle style) {
-            ErrorCode error_code;
-            auto result = CompactDecimalFormat::createInstance(in_locale, style, error_code);
-            if (error_code.isFailure()) {
-              throw ICUError(error_code);
-            }
-            return result;
-          },
-          py::arg("in_locale"), py::arg("style"));
+      "create_instance",
+      [](const _LocaleVariant &in_locale, UNumberCompactStyle style) {
+        ErrorCode error_code;
+        auto result = CompactDecimalFormat::createInstance(VARIANT_TO_LOCALE(in_locale), style, error_code);
+        if (error_code.isFailure()) {
+          throw ICUError(error_code);
+        }
+        return result;
+      },
+      py::arg("in_locale"), py::arg("style"));
   cdf.def(
          // [3] DecimalFormat::format
          "format", py::overload_cast<double, UnicodeString &, FieldPosition &>(&DecimalFormat::format, py::const_),
@@ -55,23 +44,23 @@ void init_compactdecimalformat(py::module &m) {
             return result;
           },
           py::arg("number").noconvert(), py::arg("append_to"), py::arg("pos_iter"))
-      .def(
-          // [6] DecimalFormat::format
-          "format", py::overload_cast<int32_t, UnicodeString &, FieldPosition &>(&DecimalFormat::format, py::const_),
-          py::arg("number"), py::arg("append_to"), py::arg("pos"))
-      .def(
-          // [8] DecimalFormat::format
-          "format",
-          [](const DecimalFormat &self, int32_t number, UnicodeString &append_to,
-             FieldPositionIterator *pos_iter) -> UnicodeString & {
-            ErrorCode error_code;
-            auto &result = self.format(number, append_to, pos_iter, error_code);
-            if (error_code.isFailure()) {
-              throw ICUError(error_code);
-            }
-            return result;
-          },
-          py::arg("number").noconvert(), py::arg("append_to"), py::arg("pos_iter"))
+      // .def(
+      //     // [6] DecimalFormat::format
+      //     "format", py::overload_cast<int32_t, UnicodeString &, FieldPosition &>(&DecimalFormat::format, py::const_),
+      //     py::arg("number"), py::arg("append_to"), py::arg("pos"))
+      // .def(
+      //     // [8] DecimalFormat::format
+      //     "format",
+      //     [](const DecimalFormat &self, int32_t number, UnicodeString &append_to,
+      //        FieldPositionIterator *pos_iter) -> UnicodeString & {
+      //       ErrorCode error_code;
+      //       auto &result = self.format(number, append_to, pos_iter, error_code);
+      //       if (error_code.isFailure()) {
+      //         throw ICUError(error_code);
+      //       }
+      //       return result;
+      //     },
+      //     py::arg("number").noconvert(), py::arg("append_to"), py::arg("pos_iter"))
       .def(
           // [9] DecimalFormat::format
           "format", py::overload_cast<int64_t, UnicodeString &, FieldPosition &>(&DecimalFormat::format, py::const_),
@@ -128,8 +117,8 @@ void init_compactdecimalformat(py::module &m) {
           py::arg("obj"), py::arg("append_to"), py::arg("pos_iter"))
       .def("format", py::overload_cast<double, UnicodeString &>(&NumberFormat::format, py::const_),
            py::arg("number").noconvert(), py::arg("append_to"))
-      .def("format", py::overload_cast<int32_t, UnicodeString &>(&NumberFormat::format, py::const_), py::arg("number"),
-           py::arg("append_to"))
+      // .def("format", py::overload_cast<int32_t, UnicodeString &>(&NumberFormat::format, py::const_),
+      //      py::arg("number"), py::arg("append_to"))
       .def("format", py::overload_cast<int64_t, UnicodeString &>(&NumberFormat::format, py::const_), py::arg("number"),
            py::arg("append_to"))
       .def(
@@ -146,32 +135,15 @@ void init_compactdecimalformat(py::module &m) {
   cdf.def(
          // [1] CompactDecimalFormat::parse
          "parse",
-         py::overload_cast<const UnicodeString &, Formattable &, ParsePosition &>(&CompactDecimalFormat::parse,
-                                                                                  py::const_),
+         [](const CompactDecimalFormat &self, const _UnicodeStringVariant &text, Formattable &result,
+            ParsePosition &parse_position) { self.parse(VARIANT_TO_UNISTR(text), result, parse_position); },
          py::arg("text"), py::arg("result"), py::arg("parse_position"))
-      .def(
-          // const char16_t *text -> const UnicodeString &text
-          "parse",
-          [](const CompactDecimalFormat &self, const char16_t *text, Formattable &result,
-             ParsePosition &parse_position) { self.parse(text, result, parse_position); },
-          py::arg("text"), py::arg("result"), py::arg("parse_position"))
       .def(
           // [2] CompactDecimalFormat::parse
           "parse",
-          [](const CompactDecimalFormat &self, const UnicodeString &text, Formattable &result) {
+          [](const CompactDecimalFormat &self, const _UnicodeStringVariant &text, Formattable &result) {
             ErrorCode error_code;
-            self.parse(text, result, error_code);
-            if (error_code.isFailure()) {
-              throw ICUError(error_code);
-            }
-          },
-          py::arg("text"), py::arg("result"))
-      .def(
-          // const char16_t *text -> const UnicodeString &text
-          "parse",
-          [](const CompactDecimalFormat &self, const char16_t *text, Formattable &result) {
-            ErrorCode error_code;
-            self.parse(text, result, error_code);
+            self.parse(VARIANT_TO_UNISTR(text), result, error_code);
             if (error_code.isFailure()) {
               throw ICUError(error_code);
             }
