@@ -12,27 +12,12 @@ using namespace icu;
 void init_gregocal(py::module &m) {
   // icu::Calendar
   py::class_<Calendar, UObject> cal(m, "Calendar");
-  cal.def("__copy__", &Calendar::clone)
-      .def(
-          "__deepcopy__", [](const Calendar &self, py::dict) { return self.clone(); }, py::arg("memo"))
-      .def(
-          "__eq__", [](const Calendar &self, const Calendar &other) { return self == other; }, py::is_operator(),
-          py::arg("other"))
+  cal.def(
+         "__eq__", [](const Calendar &self, const Calendar &other) { return self == other; }, py::is_operator(),
+         py::arg("other"))
       .def(
           "__ne__", [](const Calendar &self, const Calendar &other) { return self != other; }, py::is_operator(),
-          py::arg("other"))
-      .def("__repr__", [](const Calendar &self) {
-        std::stringstream ss;
-        ErrorCode error_code;
-        auto fmt = SimpleDateFormat(u"yyyy-MM-dd'T'HH:mm:ss.SSSXXX", error_code);
-        fmt.setCalendar(self);
-        UnicodeString dest;
-        fmt.format(self.getTime(error_code), dest);
-        std::string s;
-        dest.toUTF8String(s);
-        ss << "Calendar(" << s << ")";
-        return ss.str();
-      });
+          py::arg("other"));
   cal.def(
       "add",
       [](Calendar &self, UCalendarDateFields field, int32_t amount) {
@@ -76,9 +61,9 @@ void init_gregocal(py::module &m) {
   cal.def("clone", &Calendar::clone);
   cal.def_static(
          "create_instance",
-         [](const Locale &locale) {
+         [](const _LocaleVariant &locale) {
            ErrorCode error_code;
-           auto result = Calendar::createInstance(locale, error_code);
+           auto result = Calendar::createInstance(VARIANT_TO_LOCALE(locale), error_code);
            if (error_code.isFailure()) {
              throw ICUError(error_code);
            }
@@ -87,31 +72,9 @@ void init_gregocal(py::module &m) {
          py::arg("locale"))
       .def_static(
           "create_instance",
-          [](const char *locale) {
+          [](const TimeZone &zone, const _LocaleVariant &locale) {
             ErrorCode error_code;
-            auto result = Calendar::createInstance(locale, error_code);
-            if (error_code.isFailure()) {
-              throw ICUError(error_code);
-            }
-            return result;
-          },
-          py::arg("locale"))
-      .def_static(
-          "create_instance",
-          [](const TimeZone &zone, const Locale &locale) {
-            ErrorCode error_code;
-            auto result = Calendar::createInstance(zone, locale, error_code);
-            if (error_code.isFailure()) {
-              throw ICUError(error_code);
-            }
-            return result;
-          },
-          py::arg("zone"), py::arg("locale"))
-      .def_static(
-          "create_instance",
-          [](const TimeZone &zone, const char *locale) {
-            ErrorCode error_code;
-            auto result = Calendar::createInstance(zone, locale, error_code);
+            auto result = Calendar::createInstance(zone, VARIANT_TO_LOCALE(locale), error_code);
             if (error_code.isFailure()) {
               throw ICUError(error_code);
             }
@@ -170,28 +133,6 @@ void init_gregocal(py::module &m) {
         return result;
       },
       py::arg("field"));
-  cal.def(
-      "get_actual_maximum",
-      [](const Calendar &self, UCalendarDateFields field) {
-        ErrorCode error_code;
-        auto result = self.getActualMaximum(field, error_code);
-        if (error_code.isFailure()) {
-          throw ICUError(error_code);
-        }
-        return result;
-      },
-      py::arg("field"));
-  cal.def(
-      "get_actual_minimum",
-      [](const Calendar &self, UCalendarDateFields field) {
-        ErrorCode error_code;
-        auto result = self.getActualMinimum(field, error_code);
-        if (error_code.isFailure()) {
-          throw ICUError(error_code);
-        }
-        return result;
-      },
-      py::arg("field"));
   cal.def_static(
       "get_available_locales",
       []() {
@@ -226,27 +167,16 @@ void init_gregocal(py::module &m) {
   cal.def("get_greatest_minimum", py::overload_cast<UCalendarDateFields>(&Calendar::getGreatestMinimum, py::const_),
           py::arg("field"));
   cal.def_static(
-         "get_keyword_values_for_locale",
-         [](const char *key, const Locale &locale, UBool commonly_used) {
-           ErrorCode error_code;
-           auto result = Calendar::getKeywordValuesForLocale(key, locale, commonly_used, error_code);
-           if (error_code.isFailure()) {
-             throw ICUError(error_code);
-           }
-           return result;
-         },
-         py::arg("key"), py::arg("locale"), py::arg("commonly_used"))
-      .def_static(
-          "get_keyword_values_for_locale",
-          [](const char *key, const char *locale, UBool commonly_used) {
-            ErrorCode error_code;
-            auto result = Calendar::getKeywordValuesForLocale(key, locale, commonly_used, error_code);
-            if (error_code.isFailure()) {
-              throw ICUError(error_code);
-            }
-            return result;
-          },
-          py::arg("key"), py::arg("locale"), py::arg("commonly_used"));
+      "get_keyword_values_for_locale",
+      [](const char *key, const _LocaleVariant &locale, UBool commonly_used) {
+        ErrorCode error_code;
+        auto result = Calendar::getKeywordValuesForLocale(key, VARIANT_TO_LOCALE(locale), commonly_used, error_code);
+        if (error_code.isFailure()) {
+          throw ICUError(error_code);
+        }
+        return result;
+      },
+      py::arg("key"), py::arg("locale"), py::arg("commonly_used"));
   cal.def("get_least_maximum", py::overload_cast<UCalendarDateFields>(&Calendar::getLeastMaximum, py::const_),
           py::arg("field"));
   cal.def(
@@ -301,14 +231,6 @@ void init_gregocal(py::module &m) {
         return result;
       },
       py::arg("day_of_week"));
-  cal.def("in_daylight_time", [](const Calendar &self) {
-    ErrorCode error_code;
-    auto result = self.inDaylightTime(error_code);
-    if (error_code.isFailure()) {
-      throw ICUError(error_code);
-    }
-    return result;
-  });
   cal.def("is_equivalent_to", &Calendar::isEquivalentTo, py::arg("other"));
   cal.def("is_lenient", &Calendar::isLenient);
   cal.def("is_set", py::overload_cast<UCalendarDateFields>(&Calendar::isSet, py::const_), py::arg("field"));
@@ -332,16 +254,6 @@ void init_gregocal(py::module &m) {
     }
     return tz;
   });
-  cal.def(
-      "roll",
-      [](Calendar &self, UCalendarDateFields field, int32_t amount) {
-        ErrorCode error_code;
-        self.roll(field, amount, error_code);
-        if (error_code.isFailure()) {
-          throw ICUError(error_code);
-        }
-      },
-      py::arg("field"), py::arg("amount"));
   cal.def("set", py::overload_cast<int32_t, int32_t, int32_t>(&Calendar::set), py::arg("year"), py::arg("month"),
           py::arg("date"))
       .def("set", py::overload_cast<int32_t, int32_t, int32_t, int32_t, int32_t>(&Calendar::set), py::arg("year"),
@@ -395,36 +307,18 @@ void init_gregocal(py::module &m) {
              return result;
            }),
            py::arg("zone"))
-      .def(py::init([](const Locale &locale) {
+      .def(py::init([](const _LocaleVariant &locale) {
              ErrorCode error_code;
-             auto result = std::make_unique<GregorianCalendar>(locale, error_code);
+             auto result = std::make_unique<GregorianCalendar>(VARIANT_TO_LOCALE(locale), error_code);
              if (error_code.isFailure()) {
                throw ICUError(error_code);
              }
              return result;
            }),
            py::arg("locale"))
-      .def(py::init([](const char *locale) {
+      .def(py::init([](const TimeZone &zone, const _LocaleVariant &locale) {
              ErrorCode error_code;
-             auto result = std::make_unique<GregorianCalendar>(locale, error_code);
-             if (error_code.isFailure()) {
-               throw ICUError(error_code);
-             }
-             return result;
-           }),
-           py::arg("locale"))
-      .def(py::init([](const TimeZone &zone, const Locale &locale) {
-             ErrorCode error_code;
-             auto result = std::make_unique<GregorianCalendar>(zone, locale, error_code);
-             if (error_code.isFailure()) {
-               throw ICUError(error_code);
-             }
-             return result;
-           }),
-           py::arg("zone"), py::arg("locale"))
-      .def(py::init([](const TimeZone &zone, const char *locale) {
-             ErrorCode error_code;
-             auto result = std::make_unique<GregorianCalendar>(zone, locale, error_code);
+             auto result = std::make_unique<GregorianCalendar>(zone, VARIANT_TO_LOCALE(locale), error_code);
              if (error_code.isFailure()) {
                throw ICUError(error_code);
              }
