@@ -1,6 +1,7 @@
 #include "main.hpp"
 
 #if (U_ICU_VERSION_MAJOR_NUM >= 64)
+#include <pybind11/stl.h>
 #include <unicode/localebuilder.h>
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 64)
 
@@ -51,14 +52,11 @@ void init_localebuilder(py::module &m) {
       "set_language_tag",
       [](LocaleBuilder &self, const char *tag) -> LocaleBuilder & { return self.setLanguageTag(tag); }, py::arg("tag"));
   lb.def(
-        "set_locale",
-        [](LocaleBuilder &self, const Locale &locale) -> LocaleBuilder & { return self.setLocale(locale); },
-        py::arg("locale"))
-      .def(
-          // const char *locale -> const Locale &locale
-          "set_locale",
-          [](LocaleBuilder &self, const char *locale) -> LocaleBuilder & { return self.setLocale(locale); },
-          py::arg("locale"));
+      "set_locale",
+      [](LocaleBuilder &self, const _LocaleVariant &locale) -> LocaleBuilder & {
+        return self.setLocale(VARIANT_TO_LOCALE(locale));
+      },
+      py::arg("locale"));
   lb.def(
       "set_region", [](LocaleBuilder &self, const char *region) -> LocaleBuilder & { return self.setRegion(region); },
       py::arg("region"));
