@@ -109,6 +109,7 @@ void init_ulocdata(py::module &m);
 void init_uniset(py::module &m);
 void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class_<UnicodeString, Replaceable> &us);
 void init_unorm2(py::module &m);
+void init_unounclass(py::module &m);
 void init_unum(py::module &m);
 void init_unumberformatter(py::module &m);
 void init_unumberrangeformatter(py::module &m);
@@ -133,11 +134,8 @@ void init_uversion(py::module &m);
 void init_voidptr(py::module &m);
 
 ICUError::ICUError(const ErrorCode &error_code, const char *message) : error_code_(error_code) {
-  what_.append(error_code.errorName());
   if (message != nullptr && *message != 0) {
     message_.append(message);
-    what_.append(": ");
-    what_.append(message);
   }
 }
 
@@ -307,6 +305,7 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_uloc(m);
   init_ulocdata(m);
   init_unorm2(m);
+  init_unounclass(m);
   init_unum(m);
   init_unumberformatter(m);
   init_unumberrangeformatter(m);
@@ -328,8 +327,6 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_utypes(m);
   init_uversion(m);
 
-  m.attr("VERSION_INFO") = VERSION_INFO; // VERSION_INFO is defined by _build.py or CMakeLists.txt
-
   // <unicode/umachine.h>
   m.attr("INT16_MAX") = INT16_MAX;
   m.attr("INT16_MIN") = INT16_MIN;
