@@ -1,8 +1,13 @@
 #include "main.hpp"
 
 #if (U_ICU_VERSION_MAJOR_NUM >= 60)
+#include <pybind11/stl.h>
 #include <unicode/numberformatter.h>
 
+#if (U_ICU_VERSION_MAJOR_NUM >= 71)
+#include <unicode/unounclass.h>
+#endif // (U_ICU_VERSION_MAJOR_NUM >= 71)
+
 using namespace icu;
 using namespace icu::number;
 
@@ -83,6 +88,17 @@ void init_numberformatter(py::module &, py::module &m2) {
       py::arg("appendable"));
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 62)
 
+#if (U_ICU_VERSION_MAJOR_NUM >= 71)
+  fn.def("get_noun_class", [](const FormattedNumber &self) {
+    ErrorCode error_code;
+    auto result = self.getNounClass(error_code);
+    if (error_code.isFailure()) {
+      throw ICUError(error_code);
+    }
+    return result;
+  });
+#endif // (U_ICU_VERSION_MAJOR_NUM >= 71)
+
 #if (U_ICU_VERSION_MAJOR_NUM >= 68)
   fn.def("get_output_unit", [](const FormattedNumber &self) {
     ErrorCode error_code;
@@ -213,60 +229,36 @@ void init_numberformatter(py::module &, py::module &m2) {
   // icu::number::NumberFormatter
 #if (U_ICU_VERSION_MAJOR_NUM >= 62)
   nf.def_static(
-        "for_skeleton",
-        [](const UnicodeString &skeleton) {
-          ErrorCode error_code;
-          auto result = NumberFormatter::forSkeleton(skeleton, error_code);
-          if (error_code.isFailure()) {
-            throw ICUError(error_code);
-          }
-          return result;
-        },
-        py::arg("skeleton"))
-      .def_static(
-          // const char16_t *skeleton -> const UnicodeString &skeleton
-          "for_skeleton",
-          [](const char16_t *skeleton) {
-            ErrorCode error_code;
-            auto result = NumberFormatter::forSkeleton(skeleton, error_code);
-            if (error_code.isFailure()) {
-              throw ICUError(error_code);
-            }
-            return result;
-          },
-          py::arg("skeleton"));
+      "for_skeleton",
+      [](const _UnicodeStringVariant &skeleton) {
+        ErrorCode error_code;
+        auto result = NumberFormatter::forSkeleton(VARIANT_TO_UNISTR(skeleton), error_code);
+        if (error_code.isFailure()) {
+          throw ICUError(error_code);
+        }
+        return result;
+      },
+      py::arg("skeleton"));
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 62)
 
 #if (U_ICU_VERSION_MAJOR_NUM >= 64)
   nf.def_static(
-        "for_skeleton",
-        [](const UnicodeString &skeleton, UParseError &perror) {
-          ErrorCode error_code;
-          auto result = NumberFormatter::forSkeleton(skeleton, perror, error_code);
-          if (error_code.isFailure()) {
-            throw ICUError(error_code);
-          }
-          return result;
-        },
-        py::arg("skeleton"), py::arg("perror"))
-      .def_static(
-          // const char16_t *skeleton -> const UnicodeString &skeleton
-          "for_skeleton",
-          [](const char16_t *skeleton, UParseError &perror) {
-            ErrorCode error_code;
-            auto result = NumberFormatter::forSkeleton(skeleton, perror, error_code);
-            if (error_code.isFailure()) {
-              throw ICUError(error_code);
-            }
-            return result;
-          },
-          py::arg("skeleton"), py::arg("perror"));
+      "for_skeleton",
+      [](const _UnicodeStringVariant &skeleton, UParseError &perror) {
+        ErrorCode error_code;
+        auto result = NumberFormatter::forSkeleton(VARIANT_TO_UNISTR(skeleton), perror, error_code);
+        if (error_code.isFailure()) {
+          throw ICUError(error_code);
+        }
+        return result;
+      },
+      py::arg("skeleton"), py::arg("perror"));
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 64)
   nf.def_static("with_", &NumberFormatter::with);
-  nf.def_static("with_locale", &NumberFormatter::withLocale, py::arg("locale"))
-      .def_static(
-          // const char *locale -> const Locale &locale
-          "with_locale", [](const char *locale) { return NumberFormatter::withLocale(locale); }, py::arg("locale"));
+  nf.def_static(
+      "with_locale",
+      [](const _LocaleVariant &locale) { return NumberFormatter::withLocale(VARIANT_TO_LOCALE(locale)); },
+      py::arg("locale"));
 
   // icu::number::NumberFormatterSettings<LocalizedNumberFormatter>
 #if (U_ICU_VERSION_MAJOR_NUM >= 64)
@@ -488,6 +480,11 @@ void init_numberformatter(py::module &, py::module &m2) {
   pre.def_static("fixed_fraction", &Precision::fixedFraction, py::arg("min_max_fraction_places"));
   pre.def_static("fixed_significant_digits", &Precision::fixedSignificantDigits, py::arg("min_max_significant_digits"));
   pre.def_static("increment", &Precision::increment, py::arg("rounding_increment"));
+
+#if (U_ICU_VERSION_MAJOR_NUM >= 71)
+  pre.def_static("increment_exact", Precision::incrementExact, py::arg("mantissa"), py::arg("magnitude"));
+#endif // (U_ICU_VERSION_MAJOR_NUM >= 71)
+
   pre.def_static("integer", &Precision::integer);
   pre.def_static("max_fraction", &Precision::maxFraction, py::arg("max_fraction_places"));
   pre.def_static("max_significant_digits", &Precision::maxSignificantDigits, py::arg("max_significant_digits"));
@@ -527,10 +524,9 @@ void init_numberformatter(py::module &, py::module &m2) {
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 62)
   unf.def(py::init<const UnlocalizedNumberFormatter &>(), py::arg("other"));
   unf.def(
-         "locale", [](const UnlocalizedNumberFormatter &self, const Locale &locale) { return self.locale(locale); },
-         py::arg("locale"))
-      .def(
-          // const char *locale -> const Locale &locale
-          "locale", [](const UnlocalizedNumberFormatter &self, const char *locale) { return self.locale(locale); },
-          py::arg("locale"));
+      "locale",
+      [](const UnlocalizedNumberFormatter &self, const _LocaleVariant &locale) {
+        return self.locale(VARIANT_TO_LOCALE(locale));
+      },
+      py::arg("locale"));
 }
