@@ -1470,11 +1470,56 @@ void init_uchar(py::module &m) {
   m.def("u_is_uwhite_space", &u_isUWhiteSpace, py::arg("c"));
   m.def("u_is_whitespace", &u_isWhitespace, py::arg("c"));
   m.def("u_isxdigit", &u_isxdigit, py::arg("c"));
+#if (U_ICU_VERSION_MAJOR_NUM >= 70)
+  m.def(
+      "u_string_has_binary_property",
+      [](const char16_t *s, UProperty which) { return u_stringHasBinaryProperty(s, -1, which); }, py::arg("s"),
+      py::arg("which"));
+#endif // (U_ICU_VERSION_MAJOR_NUM >= 70)
   m.def("u_tolower", &u_tolower, py::arg("c"));
   m.def("u_totitle", &u_totitle, py::arg("c"));
   m.def("u_toupper", &u_toupper, py::arg("c"));
   m.def("ublock_get_code", &ublock_getCode, py::arg("c"));
 
+  m.attr("U_GC_C_MASK") = U_GC_C_MASK;
+  m.attr("U_GC_CC_MASK") = U_GC_CC_MASK;
+  m.attr("U_GC_CF_MASK") = U_GC_CF_MASK;
+  m.attr("U_GC_CN_MASK") = U_GC_CN_MASK;
+  m.attr("U_GC_CO_MASK") = U_GC_CO_MASK;
+  m.attr("U_GC_CS_MASK") = U_GC_CS_MASK;
+  m.attr("U_GC_L_MASK") = U_GC_L_MASK;
+  m.attr("U_GC_LC_MASK") = U_GC_LC_MASK;
+  m.attr("U_GC_LL_MASK") = U_GC_LL_MASK;
+  m.attr("U_GC_LM_MASK") = U_GC_LM_MASK;
+  m.attr("U_GC_LO_MASK") = U_GC_LO_MASK;
+  m.attr("U_GC_LT_MASK") = U_GC_LT_MASK;
+  m.attr("U_GC_LU_MASK") = U_GC_LU_MASK;
+  m.attr("U_GC_M_MASK") = U_GC_M_MASK;
+  m.attr("U_GC_MC_MASK") = U_GC_MC_MASK;
+  m.attr("U_GC_ME_MASK") = U_GC_ME_MASK;
+  m.attr("U_GC_MN_MASK") = U_GC_MN_MASK;
+  m.attr("U_GC_N_MASK") = U_GC_N_MASK;
+  m.attr("U_GC_ND_MASK") = U_GC_ND_MASK;
+  m.attr("U_GC_NL_MASK") = U_GC_NL_MASK;
+  m.attr("U_GC_NO_MASK") = U_GC_NO_MASK;
+  m.attr("U_GC_P_MASK") = U_GC_P_MASK;
+  m.attr("U_GC_PC_MASK") = U_GC_PC_MASK;
+  m.attr("U_GC_PD_MASK") = U_GC_PD_MASK;
+  m.attr("U_GC_PE_MASK") = U_GC_PE_MASK;
+  m.attr("U_GC_PF_MASK") = U_GC_PF_MASK;
+  m.attr("U_GC_PI_MASK") = U_GC_PI_MASK;
+  m.attr("U_GC_PO_MASK") = U_GC_PO_MASK;
+  m.attr("U_GC_PS_MASK") = U_GC_PS_MASK;
+  m.attr("U_GC_S_MASK") = U_GC_S_MASK;
+  m.attr("U_GC_SC_MASK") = U_GC_SC_MASK;
+  m.attr("U_GC_SK_MASK") = U_GC_SK_MASK;
+  m.attr("U_GC_SM_MASK") = U_GC_SM_MASK;
+  m.attr("U_GC_SO_MASK") = U_GC_SO_MASK;
+  m.attr("U_GC_Z_MASK") = U_GC_Z_MASK;
+  m.attr("U_GC_ZL_MASK") = U_GC_ZL_MASK;
+  m.attr("U_GC_ZP_MASK") = U_GC_ZP_MASK;
+  m.attr("U_GC_ZS_MASK") = U_GC_ZS_MASK;
+
   m.attr("U_NO_NUMERIC_VALUE") = U_NO_NUMERIC_VALUE;
   m.attr("U_UNICODE_VERSION") = U_UNICODE_VERSION;
   m.attr("UCHAR_MAX_VALUE") = UCHAR_MAX_VALUE;
