@@ -564,6 +564,53 @@ def test_parse():
     assert result.get_double() == d
 
 
+def test_parse_object():
+    fmt = RuleBasedNumberFormat(
+        URBNFRuleSetTag.URBNF_SPELLOUT, Locale.get_us()
+    )
+    d = -10456.0037
+    s = (
+        "minus ten thousand four hundred fifty-six"
+        " point zero zero three seven"
+    )
+
+    # void icu::NumberFormat::parseObject(
+    #       const UnicodeString &source,
+    #       Formattable &result,
+    #       ParsePosition &parse_pos
+    # )
+    result = Formattable()
+    parse_pos = ParsePosition()
+    fmt.parse_object(UnicodeString(s), result, parse_pos)
+    assert parse_pos.get_index() == len(s)
+    assert parse_pos.get_error_index() == -1
+    assert result.get_type() == Formattable.DOUBLE
+    assert result.get_double() == d
+
+    result = Formattable()
+    parse_pos = ParsePosition()
+    fmt.parse_object(s, result, parse_pos)
+    assert parse_pos.get_index() == len(s)
+    assert parse_pos.get_error_index() == -1
+    assert result.get_type() == Formattable.DOUBLE
+    assert result.get_double() == d
+
+    # void icu::Format::parseObject(
+    #       const UnicodeString &source,
+    #       Formattable &result,
+    #       UErrorCode &status
+    # )
+    result = Formattable()
+    fmt.parse_object(UnicodeString(s), result)
+    assert result.get_type() == Formattable.DOUBLE
+    assert result.get_double() == d
+
+    result = Formattable()
+    fmt.parse_object(s, result)
+    assert result.get_type() == Formattable.DOUBLE
+    assert result.get_double() == d
+
+
 def test_rule_based_number_format():
     assert issubclass(RuleBasedNumberFormat, NumberFormat)
 
