@@ -153,12 +153,16 @@ def test_create_instance():
     assert isinstance(test1, RuleBasedCollator)
     rules1 = test1.get_rules()
 
+    test1a = Collator.create_instance(str(Locale.get_default()))
+    assert isinstance(test1a, RuleBasedCollator)
+    rules1a = test1a.get_rules()
+    assert rules1 == rules1a
+
     # [2]
     # static Collator *icu::Collator::createInstance(UErrorCode &err)
     test2 = Collator.create_instance()
     assert isinstance(test2, RuleBasedCollator)
     rules2 = test2.get_rules()
-
     assert rules1 == rules2
 
 
@@ -336,6 +340,24 @@ def test_get_display_name():
         assert id(result) == id(name1)
         assert name1 == "Japanese"
 
+        name1.remove()
+        result = Collator.get_display_name("ja", display_locale, name1)
+        assert isinstance(result, UnicodeString)
+        assert id(result) == id(name1)
+        assert name1 == "Japanese"
+
+        name1.remove()
+        result = Collator.get_display_name(object_locale, "en_US", name1)
+        assert isinstance(result, UnicodeString)
+        assert id(result) == id(name1)
+        assert name1 == "Japanese"
+
+        name1.remove()
+        result = Collator.get_display_name("ja", "en_US", name1)
+        assert isinstance(result, UnicodeString)
+        assert id(result) == id(name1)
+        assert name1 == "Japanese"
+
         # [2]
         # static UnicodeString &icu::Collator::getDisplayName(
         #       const Locale &objectLocale,
@@ -346,6 +368,12 @@ def test_get_display_name():
         assert isinstance(result, UnicodeString)
         assert id(result) == id(name2)
         assert name2 == "Japanese"
+
+        name2.remove()
+        result = Collator.get_display_name("ja", name2)
+        assert isinstance(result, UnicodeString)
+        assert id(result) == id(name2)
+        assert name2 == "Japanese"
     finally:
         if default_locale:
             Locale.set_default(default_locale)
@@ -381,6 +409,13 @@ def test_get_functional_equivalent():
     assert result == Locale.get_japanese()
     assert is_available
 
+    result, is_available = Collator.get_functional_equivalent(
+        "collation", "ja"
+    )
+    assert isinstance(result, Locale)
+    assert result == Locale.get_japanese()
+    assert is_available
+
 
 def test_get_keywords():
     # static StringEnumeration *icu::Collator::getKeywords(UErrorCode &status)
@@ -410,6 +445,10 @@ def test_get_keywords():
     assert isinstance(it, StringEnumeration)
     assert list(it) == ["standard", "unihan", "emoji", "eor", "search"]
 
+    it = Collator.get_keyword_values_for_locale("collation", "ja-JP", True)
+    assert isinstance(it, StringEnumeration)
+    assert list(it) == ["standard", "unihan", "emoji", "eor", "search"]
+
 
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 53, reason="ICU4C<53")
 def test_get_max_variable():
@@ -685,6 +724,18 @@ def test_rule_based_collator():
     test6 = RuleBasedCollator(test1)
     assert test6.get_rules() == rules
 
+    # int32_t icu::RuleBasedCollator::cloneBinary(
+    #       uint8_t *buffer,
+    #       int32_t capacity,
+    #       UErrorCode &status
+    # )
+    test1.set_attribute(
+        UColAttribute.UCOL_STRENGTH, UColAttributeValue.UCOL_PRIMARY
+    )
+    buffer = test1.clone_binary()
+    assert isinstance(buffer, bytes)
+    assert len(buffer) > 0
+
     # [7]
     # icu::RuleBasedCollator::RuleBasedCollator(
     #       const uint8_t *bin,
@@ -692,14 +743,28 @@ def test_rule_based_collator():
     #       const RuleBasedCollator *base,
     #       UErrorCode &status
     # )
-    # buffer = test1.clone_binary()
-    # assert isinstance(buffer, list)
-    # assert len(buffer) > 0
-    # root = Collator.create_instance(Locale.get_root())
-    # test7 = RuleBasedCollator(buffer, len(buffer), root)
-    # rules7 = test7.get_rules()
-    # assert rules7 == rules
-    pass  # NotImplemented
+    root = Collator.create_instance(Locale.get_root())
+    test7 = RuleBasedCollator(buffer, len(buffer), root)
+    assert test1 == test7
+    assert (
+        test7.get_attribute(UColAttribute.UCOL_STRENGTH)
+        == UColAttributeValue.UCOL_PRIMARY
+    )
+
+    buffer2 = test7.clone_binary()
+    assert len(buffer) == len(buffer2)
+    assert buffer == buffer2
+
+    test7a = RuleBasedCollator(buffer2, -1, root)
+    assert test1 == test7 == test7a
+    assert (
+        test7a.get_attribute(UColAttribute.UCOL_STRENGTH)
+        == UColAttributeValue.UCOL_PRIMARY
+    )
+
+    buffer3 = test7a.clone_binary()
+    assert len(buffer) == len(buffer3)
+    assert buffer == buffer3
 
 
 def test_sort():
